@@ -6,8 +6,8 @@
 #include "curl-common.h"
 
 SEXP R_curl_fetch_memory(SEXP url, SEXP ptr, SEXP nonblocking){
-  if (!isString(url) || length(url) != 1)
-    error("Argument 'url' must be string.");
+  if (!Rf_isString(url) || Rf_length(url) != 1)
+    Rf_error("Argument 'url' must be string.");
 
   /* get the handle */
   CURL *handle = get_handle(ptr);
@@ -25,7 +25,7 @@ SEXP R_curl_fetch_memory(SEXP url, SEXP ptr, SEXP nonblocking){
   curl_easy_setopt(handle, CURLOPT_WRITEDATA, &body);
 
   /* perform blocking request */
-  CURLcode status = asLogical(nonblocking) ?
+  CURLcode status = Rf_asLogical(nonblocking) ?
     curl_perform_with_interrupt(handle) : curl_easy_perform(handle);
 
   /* Reset for reuse */
@@ -39,7 +39,7 @@ SEXP R_curl_fetch_memory(SEXP url, SEXP ptr, SEXP nonblocking){
   }
 
   /* create output */
-  SEXP out = PROTECT(allocVector(RAWSXP, body.size));
+  SEXP out = PROTECT(Rf_allocVector(RAWSXP, body.size));
 
   /* copy only if there is actual content */
   if(body.size)
@@ -52,10 +52,10 @@ SEXP R_curl_fetch_memory(SEXP url, SEXP ptr, SEXP nonblocking){
 }
 
 SEXP R_curl_fetch_disk(SEXP url, SEXP ptr, SEXP path, SEXP mode, SEXP nonblocking){
-  if (!isString(url) || length(url) != 1)
-    error("Argument 'url' must be string.");
-  if (!isString(path) || length(path) != 1)
-    error("`path` must be string.");
+  if (!Rf_isString(url) || Rf_length(url) != 1)
+    Rf_error("Argument 'url' must be string.");
+  if (!Rf_isString(path) || Rf_length(path) != 1)
+    Rf_error("`path` must be string.");
 
   /* get the handle */
   CURL *handle = get_handle(ptr);
@@ -68,14 +68,14 @@ SEXP R_curl_fetch_disk(SEXP url, SEXP ptr, SEXP path, SEXP mode, SEXP nonblockin
   reset_errbuf(get_ref(ptr));
 
   /* open file */
-  FILE *dest = fopen(CHAR(asChar(path)), CHAR(asChar(mode)));
+  FILE *dest = fopen(CHAR(Rf_asChar(path)), CHAR(Rf_asChar(mode)));
   if(!dest)
-    error("Failed to open file %s.", CHAR(asChar(path)));
+    Rf_error("Failed to open file %s.", CHAR(Rf_asChar(path)));
   curl_easy_setopt(handle, CURLOPT_WRITEFUNCTION, push_disk);
   curl_easy_setopt(handle, CURLOPT_WRITEDATA, dest);
 
   /* perform blocking request */
-  CURLcode status = asLogical(nonblocking) ?
+  CURLcode status = Rf_asLogical(nonblocking) ?
     curl_perform_with_interrupt(handle): curl_easy_perform(handle);
 
   /* cleanup */
